"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_privateDnsZones(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_DNS_ZONES_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES_VIRTUAL_NETWORK_LINKS_FIELD_NUMBER: builtins.int
    @property
    def private_dns_zones(self) -> global___PrivateDnsZones: ...
    @property
    def private_dns_zones_virtual_network_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesVirtualNetworkLinks]: ...
    def __init__(
        self,
        *,
        private_dns_zones: global___PrivateDnsZones | None = ...,
        private_dns_zones_virtual_network_links: collections.abc.Iterable[global___PrivateDnsZonesVirtualNetworkLinks] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_dns_zones", b"private_dns_zones"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_dns_zones", b"private_dns_zones", "private_dns_zones_virtual_network_links", b"private_dns_zones_virtual_network_links"]) -> None: ...

global___Microsoft_Network_privateDnsZones = Microsoft_Network_privateDnsZones

@typing_extensions.final
class PrivateDnsZonesTXT(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesTXT = PrivateDnsZonesTXT

@typing_extensions.final
class PrivateDnsZonesSRV(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesSRV = PrivateDnsZonesSRV

@typing_extensions.final
class PrivateDnsZonesSOA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesSOA = PrivateDnsZonesSOA

@typing_extensions.final
class PrivateDnsZonesPTR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesPTR = PrivateDnsZonesPTR

@typing_extensions.final
class PrivateDnsZonesMX(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesMX = PrivateDnsZonesMX

@typing_extensions.final
class PrivateDnsZonesCNAME(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesCNAME = PrivateDnsZonesCNAME

@typing_extensions.final
class PrivateDnsZonesAAAA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesAAAA = PrivateDnsZonesAAAA

@typing_extensions.final
class PrivateDnsZonesA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    A_RECORDS_FIELD_NUMBER: builtins.int
    AAAA_RECORDS_FIELD_NUMBER: builtins.int
    CNAME_RECORD_FIELD_NUMBER: builtins.int
    MX_RECORDS_FIELD_NUMBER: builtins.int
    PTR_RECORDS_FIELD_NUMBER: builtins.int
    SOA_RECORD_FIELD_NUMBER: builtins.int
    SRV_RECORDS_FIELD_NUMBER: builtins.int
    TXT_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    etag: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ttl: builtins.int
    @property
    def a_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ARecord]: ...
    @property
    def aaaa_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AaaaRecord]: ...
    @property
    def cname_record(self) -> global___CnameRecord: ...
    @property
    def mx_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MxRecord]: ...
    @property
    def ptr_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PtrRecord]: ...
    @property
    def soa_record(self) -> global___SoaRecord: ...
    @property
    def srv_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SrvRecord]: ...
    @property
    def txt_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxtRecord]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        etag: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ttl: builtins.int = ...,
        a_records: collections.abc.Iterable[global___ARecord] | None = ...,
        aaaa_records: collections.abc.Iterable[global___AaaaRecord] | None = ...,
        cname_record: global___CnameRecord | None = ...,
        mx_records: collections.abc.Iterable[global___MxRecord] | None = ...,
        ptr_records: collections.abc.Iterable[global___PtrRecord] | None = ...,
        soa_record: global___SoaRecord | None = ...,
        srv_records: collections.abc.Iterable[global___SrvRecord] | None = ...,
        txt_records: collections.abc.Iterable[global___TxtRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cname_record", b"cname_record", "resource_info", b"resource_info", "soa_record", b"soa_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["a_records", b"a_records", "aaaa_records", b"aaaa_records", "cname_record", b"cname_record", "etag", b"etag", "metadata", b"metadata", "mx_records", b"mx_records", "name", b"name", "ptr_records", b"ptr_records", "resource_info", b"resource_info", "soa_record", b"soa_record", "srv_records", b"srv_records", "ttl", b"ttl", "txt_records", b"txt_records"]) -> None: ...

global___PrivateDnsZonesA = PrivateDnsZonesA

@typing_extensions.final
class TxtRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        value: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___TxtRecord = TxtRecord

@typing_extensions.final
class SrvRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    priority: builtins.int
    weight: builtins.int
    port: builtins.int
    target: builtins.str
    def __init__(
        self,
        *,
        priority: builtins.int = ...,
        weight: builtins.int = ...,
        port: builtins.int = ...,
        target: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "priority", b"priority", "target", b"target", "weight", b"weight"]) -> None: ...

global___SrvRecord = SrvRecord

@typing_extensions.final
class SoaRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    REFRESH_TIME_FIELD_NUMBER: builtins.int
    RETRY_TIME_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    MINIMUM_TTL_FIELD_NUMBER: builtins.int
    host: builtins.str
    email: builtins.str
    serial_number: builtins.int
    refresh_time: builtins.int
    retry_time: builtins.int
    expire_time: builtins.int
    minimum_ttl: builtins.int
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        email: builtins.str = ...,
        serial_number: builtins.int = ...,
        refresh_time: builtins.int = ...,
        retry_time: builtins.int = ...,
        expire_time: builtins.int = ...,
        minimum_ttl: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "expire_time", b"expire_time", "host", b"host", "minimum_ttl", b"minimum_ttl", "refresh_time", b"refresh_time", "retry_time", b"retry_time", "serial_number", b"serial_number"]) -> None: ...

global___SoaRecord = SoaRecord

@typing_extensions.final
class PtrRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PTRDNAME_FIELD_NUMBER: builtins.int
    ptrdname: builtins.str
    def __init__(
        self,
        *,
        ptrdname: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ptrdname", b"ptrdname"]) -> None: ...

global___PtrRecord = PtrRecord

@typing_extensions.final
class MxRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERENCE_FIELD_NUMBER: builtins.int
    EXCHANGE_FIELD_NUMBER: builtins.int
    preference: builtins.int
    exchange: builtins.str
    def __init__(
        self,
        *,
        preference: builtins.int = ...,
        exchange: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exchange", b"exchange", "preference", b"preference"]) -> None: ...

global___MxRecord = MxRecord

@typing_extensions.final
class CnameRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CNAME_FIELD_NUMBER: builtins.int
    cname: builtins.str
    def __init__(
        self,
        *,
        cname: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cname", b"cname"]) -> None: ...

global___CnameRecord = CnameRecord

@typing_extensions.final
class AaaaRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    ipv6_address: builtins.str
    def __init__(
        self,
        *,
        ipv6_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv6_address", b"ipv6_address"]) -> None: ...

global___AaaaRecord = AaaaRecord

@typing_extensions.final
class ARecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    ipv4_address: builtins.str
    def __init__(
        self,
        *,
        ipv4_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv4_address", b"ipv4_address"]) -> None: ...

global___ARecord = ARecord

@typing_extensions.final
class PrivateDnsZonesVirtualNetworkLinks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_FIELD_NUMBER: builtins.int
    REGISTRATION_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    etag: builtins.str
    virtual_network: builtins.str
    registration_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        etag: builtins.str = ...,
        virtual_network: builtins.str = ...,
        registration_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "name", b"name", "registration_enabled", b"registration_enabled", "resource_info", b"resource_info", "tags", b"tags", "virtual_network", b"virtual_network"]) -> None: ...

global___PrivateDnsZonesVirtualNetworkLinks = PrivateDnsZonesVirtualNetworkLinks

@typing_extensions.final
class PrivateDnsZones(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__A_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__AAAA_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__CNAME_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__MX_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__PTR_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__SOA_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__SRV_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONES__TXT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    etag: builtins.str
    @property
    def private_dns_zones__a(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesA]: ...
    @property
    def private_dns_zones__aaaa(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesAAAA]: ...
    @property
    def private_dns_zones__cname(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesCNAME]: ...
    @property
    def private_dns_zones__mx(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesMX]: ...
    @property
    def private_dns_zones__ptr(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesPTR]: ...
    @property
    def private_dns_zones__soa(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesSOA]: ...
    @property
    def private_dns_zones__srv(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesSRV]: ...
    @property
    def private_dns_zones__txt(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZonesTXT]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        etag: builtins.str = ...,
        private_dns_zones__a: collections.abc.Iterable[global___PrivateDnsZonesA] | None = ...,
        private_dns_zones__aaaa: collections.abc.Iterable[global___PrivateDnsZonesAAAA] | None = ...,
        private_dns_zones__cname: collections.abc.Iterable[global___PrivateDnsZonesCNAME] | None = ...,
        private_dns_zones__mx: collections.abc.Iterable[global___PrivateDnsZonesMX] | None = ...,
        private_dns_zones__ptr: collections.abc.Iterable[global___PrivateDnsZonesPTR] | None = ...,
        private_dns_zones__soa: collections.abc.Iterable[global___PrivateDnsZonesSOA] | None = ...,
        private_dns_zones__srv: collections.abc.Iterable[global___PrivateDnsZonesSRV] | None = ...,
        private_dns_zones__txt: collections.abc.Iterable[global___PrivateDnsZonesTXT] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "location", b"location", "name", b"name", "private_dns_zones__a", b"private_dns_zones__a", "private_dns_zones__aaaa", b"private_dns_zones__aaaa", "private_dns_zones__cname", b"private_dns_zones__cname", "private_dns_zones__mx", b"private_dns_zones__mx", "private_dns_zones__ptr", b"private_dns_zones__ptr", "private_dns_zones__soa", b"private_dns_zones__soa", "private_dns_zones__srv", b"private_dns_zones__srv", "private_dns_zones__txt", b"private_dns_zones__txt", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___PrivateDnsZones = PrivateDnsZones



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HealthcareConsentStoreXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___HealthcareConsentStoreXTimeouts = HealthcareConsentStoreXTimeouts

@typing_extensions.final
class HealthcareConsentStore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATASET_FIELD_NUMBER: builtins.int
    DEFAULT_CONSENT_TTL_FIELD_NUMBER: builtins.int
    ENABLE_CONSENT_CREATE_ON_UPDATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset: builtins.str
    default_consent_ttl: builtins.str
    enable_consent_create_on_update: builtins.bool
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    @property
    def timeouts(self) -> global___HealthcareConsentStoreXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset: builtins.str = ...,
        default_consent_ttl: builtins.str = ...,
        enable_consent_create_on_update: builtins.bool = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        timeouts: global___HealthcareConsentStoreXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset", b"dataset", "default_consent_ttl", b"default_consent_ttl", "enable_consent_create_on_update", b"enable_consent_create_on_update", "id", b"id", "labels", b"labels", "name", b"name", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___HealthcareConsentStore = HealthcareConsentStore

@typing_extensions.final
class HealthcareConsentStoreIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareConsentStoreIamBindingXCondition = HealthcareConsentStoreIamBindingXCondition

@typing_extensions.final
class HealthcareConsentStoreIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSENT_STORE_ID_FIELD_NUMBER: builtins.int
    DATASET_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    consent_store_id: builtins.str
    dataset: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareConsentStoreIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consent_store_id: builtins.str = ...,
        dataset: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___HealthcareConsentStoreIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "consent_store_id", b"consent_store_id", "dataset", b"dataset", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareConsentStoreIamBinding = HealthcareConsentStoreIamBinding

@typing_extensions.final
class HealthcareConsentStoreIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareConsentStoreIamMemberXCondition = HealthcareConsentStoreIamMemberXCondition

@typing_extensions.final
class HealthcareConsentStoreIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSENT_STORE_ID_FIELD_NUMBER: builtins.int
    DATASET_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    consent_store_id: builtins.str
    dataset: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareConsentStoreIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consent_store_id: builtins.str = ...,
        dataset: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___HealthcareConsentStoreIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "consent_store_id", b"consent_store_id", "dataset", b"dataset", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareConsentStoreIamMember = HealthcareConsentStoreIamMember

@typing_extensions.final
class HealthcareConsentStoreIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSENT_STORE_ID_FIELD_NUMBER: builtins.int
    DATASET_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    consent_store_id: builtins.str
    dataset: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consent_store_id: builtins.str = ...,
        dataset: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consent_store_id", b"consent_store_id", "dataset", b"dataset", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___HealthcareConsentStoreIamPolicy = HealthcareConsentStoreIamPolicy

@typing_extensions.final
class HealthcareDatasetXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___HealthcareDatasetXTimeouts = HealthcareDatasetXTimeouts

@typing_extensions.final
class HealthcareDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    time_zone: builtins.str
    @property
    def timeouts(self) -> global___HealthcareDatasetXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        time_zone: builtins.str = ...,
        timeouts: global___HealthcareDatasetXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "time_zone", b"time_zone", "timeouts", b"timeouts"]) -> None: ...

global___HealthcareDataset = HealthcareDataset

@typing_extensions.final
class HealthcareDatasetIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareDatasetIamBindingXCondition = HealthcareDatasetIamBindingXCondition

@typing_extensions.final
class HealthcareDatasetIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareDatasetIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___HealthcareDatasetIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "dataset_id", b"dataset_id", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareDatasetIamBinding = HealthcareDatasetIamBinding

@typing_extensions.final
class HealthcareDatasetIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareDatasetIamMemberXCondition = HealthcareDatasetIamMemberXCondition

@typing_extensions.final
class HealthcareDatasetIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareDatasetIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___HealthcareDatasetIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "dataset_id", b"dataset_id", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareDatasetIamMember = HealthcareDatasetIamMember

@typing_extensions.final
class HealthcareDatasetIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_id", b"dataset_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___HealthcareDatasetIamPolicy = HealthcareDatasetIamPolicy

@typing_extensions.final
class HealthcareDicomStoreXNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    pubsub_topic: builtins.str
    def __init__(
        self,
        *,
        pubsub_topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_topic", b"pubsub_topic"]) -> None: ...

global___HealthcareDicomStoreXNotificationConfig = HealthcareDicomStoreXNotificationConfig

@typing_extensions.final
class HealthcareDicomStoreXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___HealthcareDicomStoreXTimeouts = HealthcareDicomStoreXTimeouts

@typing_extensions.final
class HealthcareDicomStore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATASET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    self_link: builtins.str
    @property
    def notification_config(self) -> global___HealthcareDicomStoreXNotificationConfig: ...
    @property
    def timeouts(self) -> global___HealthcareDicomStoreXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        self_link: builtins.str = ...,
        notification_config: global___HealthcareDicomStoreXNotificationConfig | None = ...,
        timeouts: global___HealthcareDicomStoreXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_config", b"notification_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset", b"dataset", "id", b"id", "labels", b"labels", "name", b"name", "notification_config", b"notification_config", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___HealthcareDicomStore = HealthcareDicomStore

@typing_extensions.final
class HealthcareDicomStoreIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareDicomStoreIamBindingXCondition = HealthcareDicomStoreIamBindingXCondition

@typing_extensions.final
class HealthcareDicomStoreIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DICOM_STORE_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dicom_store_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareDicomStoreIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dicom_store_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___HealthcareDicomStoreIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "dicom_store_id", b"dicom_store_id", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareDicomStoreIamBinding = HealthcareDicomStoreIamBinding

@typing_extensions.final
class HealthcareDicomStoreIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareDicomStoreIamMemberXCondition = HealthcareDicomStoreIamMemberXCondition

@typing_extensions.final
class HealthcareDicomStoreIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DICOM_STORE_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dicom_store_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareDicomStoreIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dicom_store_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___HealthcareDicomStoreIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "dicom_store_id", b"dicom_store_id", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareDicomStoreIamMember = HealthcareDicomStoreIamMember

@typing_extensions.final
class HealthcareDicomStoreIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DICOM_STORE_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dicom_store_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dicom_store_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dicom_store_id", b"dicom_store_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___HealthcareDicomStoreIamPolicy = HealthcareDicomStoreIamPolicy

@typing_extensions.final
class HealthcareFhirStoreXNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    pubsub_topic: builtins.str
    def __init__(
        self,
        *,
        pubsub_topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_topic", b"pubsub_topic"]) -> None: ...

global___HealthcareFhirStoreXNotificationConfig = HealthcareFhirStoreXNotificationConfig

@typing_extensions.final
class HealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECURSIVE_STRUCTURE_DEPTH_FIELD_NUMBER: builtins.int
    SCHEMA_TYPE_FIELD_NUMBER: builtins.int
    recursive_structure_depth: builtins.float
    schema_type: builtins.str
    def __init__(
        self,
        *,
        recursive_structure_depth: builtins.float = ...,
        schema_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["recursive_structure_depth", b"recursive_structure_depth", "schema_type", b"schema_type"]) -> None: ...

global___HealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig = HealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig

@typing_extensions.final
class HealthcareFhirStoreXStreamConfigsXBigqueryDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_URI_FIELD_NUMBER: builtins.int
    SCHEMA_CONFIG_FIELD_NUMBER: builtins.int
    dataset_uri: builtins.str
    @property
    def schema_config(self) -> global___HealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig: ...
    def __init__(
        self,
        *,
        dataset_uri: builtins.str = ...,
        schema_config: global___HealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["schema_config", b"schema_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_uri", b"dataset_uri", "schema_config", b"schema_config"]) -> None: ...

global___HealthcareFhirStoreXStreamConfigsXBigqueryDestination = HealthcareFhirStoreXStreamConfigsXBigqueryDestination

@typing_extensions.final
class HealthcareFhirStoreXStreamConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    BIGQUERY_DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def bigquery_destination(self) -> global___HealthcareFhirStoreXStreamConfigsXBigqueryDestination: ...
    def __init__(
        self,
        *,
        resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        bigquery_destination: global___HealthcareFhirStoreXStreamConfigsXBigqueryDestination | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_destination", b"bigquery_destination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_destination", b"bigquery_destination", "resource_types", b"resource_types"]) -> None: ...

global___HealthcareFhirStoreXStreamConfigs = HealthcareFhirStoreXStreamConfigs

@typing_extensions.final
class HealthcareFhirStoreXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___HealthcareFhirStoreXTimeouts = HealthcareFhirStoreXTimeouts

@typing_extensions.final
class HealthcareFhirStore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATASET_FIELD_NUMBER: builtins.int
    DISABLE_REFERENTIAL_INTEGRITY_FIELD_NUMBER: builtins.int
    DISABLE_RESOURCE_VERSIONING_FIELD_NUMBER: builtins.int
    ENABLE_HISTORY_IMPORT_FIELD_NUMBER: builtins.int
    ENABLE_UPDATE_CREATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    STREAM_CONFIGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset: builtins.str
    disable_referential_integrity: builtins.bool
    disable_resource_versioning: builtins.bool
    enable_history_import: builtins.bool
    enable_update_create: builtins.bool
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    self_link: builtins.str
    version: builtins.str
    @property
    def notification_config(self) -> global___HealthcareFhirStoreXNotificationConfig: ...
    @property
    def stream_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthcareFhirStoreXStreamConfigs]: ...
    @property
    def timeouts(self) -> global___HealthcareFhirStoreXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset: builtins.str = ...,
        disable_referential_integrity: builtins.bool = ...,
        disable_resource_versioning: builtins.bool = ...,
        enable_history_import: builtins.bool = ...,
        enable_update_create: builtins.bool = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        self_link: builtins.str = ...,
        version: builtins.str = ...,
        notification_config: global___HealthcareFhirStoreXNotificationConfig | None = ...,
        stream_configs: collections.abc.Iterable[global___HealthcareFhirStoreXStreamConfigs] | None = ...,
        timeouts: global___HealthcareFhirStoreXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_config", b"notification_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset", b"dataset", "disable_referential_integrity", b"disable_referential_integrity", "disable_resource_versioning", b"disable_resource_versioning", "enable_history_import", b"enable_history_import", "enable_update_create", b"enable_update_create", "id", b"id", "labels", b"labels", "name", b"name", "notification_config", b"notification_config", "resource_info", b"resource_info", "self_link", b"self_link", "stream_configs", b"stream_configs", "timeouts", b"timeouts", "version", b"version"]) -> None: ...

global___HealthcareFhirStore = HealthcareFhirStore

@typing_extensions.final
class HealthcareFhirStoreIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareFhirStoreIamBindingXCondition = HealthcareFhirStoreIamBindingXCondition

@typing_extensions.final
class HealthcareFhirStoreIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FHIR_STORE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    fhir_store_id: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareFhirStoreIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        fhir_store_id: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___HealthcareFhirStoreIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "fhir_store_id", b"fhir_store_id", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareFhirStoreIamBinding = HealthcareFhirStoreIamBinding

@typing_extensions.final
class HealthcareFhirStoreIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareFhirStoreIamMemberXCondition = HealthcareFhirStoreIamMemberXCondition

@typing_extensions.final
class HealthcareFhirStoreIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FHIR_STORE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    fhir_store_id: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareFhirStoreIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        fhir_store_id: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___HealthcareFhirStoreIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "fhir_store_id", b"fhir_store_id", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareFhirStoreIamMember = HealthcareFhirStoreIamMember

@typing_extensions.final
class HealthcareFhirStoreIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    FHIR_STORE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    fhir_store_id: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        fhir_store_id: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "fhir_store_id", b"fhir_store_id", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___HealthcareFhirStoreIamPolicy = HealthcareFhirStoreIamPolicy

@typing_extensions.final
class HealthcareHl7V2StoreXNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    pubsub_topic: builtins.str
    def __init__(
        self,
        *,
        pubsub_topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_topic", b"pubsub_topic"]) -> None: ...

global___HealthcareHl7V2StoreXNotificationConfig = HealthcareHl7V2StoreXNotificationConfig

@typing_extensions.final
class HealthcareHl7V2StoreXNotificationConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    filter: builtins.str
    pubsub_topic: builtins.str
    def __init__(
        self,
        *,
        filter: builtins.str = ...,
        pubsub_topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter", "pubsub_topic", b"pubsub_topic"]) -> None: ...

global___HealthcareHl7V2StoreXNotificationConfigs = HealthcareHl7V2StoreXNotificationConfigs

@typing_extensions.final
class HealthcareHl7V2StoreXParserConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_NULL_HEADER_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SEGMENT_TERMINATOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    allow_null_header: builtins.bool
    schema: builtins.str
    segment_terminator: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        allow_null_header: builtins.bool = ...,
        schema: builtins.str = ...,
        segment_terminator: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_null_header", b"allow_null_header", "schema", b"schema", "segment_terminator", b"segment_terminator", "version", b"version"]) -> None: ...

global___HealthcareHl7V2StoreXParserConfig = HealthcareHl7V2StoreXParserConfig

@typing_extensions.final
class HealthcareHl7V2StoreXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___HealthcareHl7V2StoreXTimeouts = HealthcareHl7V2StoreXTimeouts

@typing_extensions.final
class HealthcareHl7V2Store(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATASET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIGS_FIELD_NUMBER: builtins.int
    PARSER_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    dataset: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    self_link: builtins.str
    @property
    def notification_config(self) -> global___HealthcareHl7V2StoreXNotificationConfig: ...
    @property
    def notification_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthcareHl7V2StoreXNotificationConfigs]: ...
    @property
    def parser_config(self) -> global___HealthcareHl7V2StoreXParserConfig: ...
    @property
    def timeouts(self) -> global___HealthcareHl7V2StoreXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        dataset: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        self_link: builtins.str = ...,
        notification_config: global___HealthcareHl7V2StoreXNotificationConfig | None = ...,
        notification_configs: collections.abc.Iterable[global___HealthcareHl7V2StoreXNotificationConfigs] | None = ...,
        parser_config: global___HealthcareHl7V2StoreXParserConfig | None = ...,
        timeouts: global___HealthcareHl7V2StoreXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_config", b"notification_config", "parser_config", b"parser_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset", b"dataset", "id", b"id", "labels", b"labels", "name", b"name", "notification_config", b"notification_config", "notification_configs", b"notification_configs", "parser_config", b"parser_config", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___HealthcareHl7V2Store = HealthcareHl7V2Store

@typing_extensions.final
class HealthcareHl7V2StoreIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareHl7V2StoreIamBindingXCondition = HealthcareHl7V2StoreIamBindingXCondition

@typing_extensions.final
class HealthcareHl7V2StoreIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    HL7_V2_STORE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    hl7_v2_store_id: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareHl7V2StoreIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        hl7_v2_store_id: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___HealthcareHl7V2StoreIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "hl7_v2_store_id", b"hl7_v2_store_id", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareHl7V2StoreIamBinding = HealthcareHl7V2StoreIamBinding

@typing_extensions.final
class HealthcareHl7V2StoreIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___HealthcareHl7V2StoreIamMemberXCondition = HealthcareHl7V2StoreIamMemberXCondition

@typing_extensions.final
class HealthcareHl7V2StoreIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    HL7_V2_STORE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    hl7_v2_store_id: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___HealthcareHl7V2StoreIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        hl7_v2_store_id: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___HealthcareHl7V2StoreIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "hl7_v2_store_id", b"hl7_v2_store_id", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___HealthcareHl7V2StoreIamMember = HealthcareHl7V2StoreIamMember

@typing_extensions.final
class HealthcareHl7V2StoreIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    HL7_V2_STORE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    hl7_v2_store_id: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        hl7_v2_store_id: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "hl7_v2_store_id", b"hl7_v2_store_id", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___HealthcareHl7V2StoreIamPolicy = HealthcareHl7V2StoreIamPolicy
